Index: src/AST/Decl.hpp
===================================================================
--- src/AST/Decl.hpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Decl.hpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -411,9 +411,9 @@
 };
 
-class InlineValueDecl final : public DeclWithType {
+class InlineMemberDecl final : public DeclWithType {
 public:
 	ptr<Type> type;
 
-	InlineValueDecl( const CodeLocation & loc, const std::string & name, const Type * type,
+	InlineMemberDecl( const CodeLocation & loc, const std::string & name, const Type * type,
 		Storage::Classes storage = {}, Linkage::Spec linkage = Linkage::Cforall,
 		std::vector< ptr<Attribute> > && attrs = {}, Function::Specs fs = {} )
@@ -425,5 +425,5 @@
 	const DeclWithType * accept( Visitor& v ) const override { return v.visit( this ); }
 private:
-	InlineValueDecl * clone() const override { return new InlineValueDecl{ *this }; }
+	InlineMemberDecl * clone() const override { return new InlineMemberDecl{ *this }; }
 	MUTATE_FRIEND
 };
Index: src/AST/Fwd.hpp
===================================================================
--- src/AST/Fwd.hpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Fwd.hpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -37,5 +37,5 @@
 class DirectiveDecl;
 class StaticAssertDecl;
-class InlineValueDecl;
+class InlineMemberDecl;
 
 class Stmt;
Index: src/AST/Pass.hpp
===================================================================
--- src/AST/Pass.hpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Pass.hpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -141,5 +141,5 @@
 	const ast::DirectiveDecl *    visit( const ast::DirectiveDecl        * ) override final;
 	const ast::StaticAssertDecl * visit( const ast::StaticAssertDecl     * ) override final;
-	const ast::DeclWithType	*     visit( const ast::InlineValueDecl      * ) override final;
+	const ast::DeclWithType	*     visit( const ast::InlineMemberDecl      * ) override final;
 	const ast::CompoundStmt *     visit( const ast::CompoundStmt         * ) override final;
 	const ast::Stmt *             visit( const ast::ExprStmt             * ) override final;
Index: src/AST/Pass.impl.hpp
===================================================================
--- src/AST/Pass.impl.hpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Pass.impl.hpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -805,11 +805,11 @@
 // DeclWithType
 template< typename core_t >
-const ast::DeclWithType * ast::Pass< core_t >::visit( const ast::InlineValueDecl * node ) {
-	VISIT_START( node );
-
-	if ( __visit_children() ) {
-		{
-			guard_symtab guard { *this };
-			maybe_accept( node, &InlineValueDecl::type );
+const ast::DeclWithType * ast::Pass< core_t >::visit( const ast::InlineMemberDecl * node ) {
+	VISIT_START( node );
+
+	if ( __visit_children() ) {
+		{
+			guard_symtab guard { *this };
+			maybe_accept( node, &InlineMemberDecl::type );
 		}
 	}
Index: src/AST/Print.cpp
===================================================================
--- src/AST/Print.cpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Print.cpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -401,5 +401,5 @@
 	}
 
-	virtual const ast::DeclWithType * visit( const ast::InlineValueDecl * node ) override final {
+	virtual const ast::DeclWithType * visit( const ast::InlineMemberDecl * node ) override final {
 		os << "inline ";
 		if ( ! node->name.empty() ) os << node->name;
Index: src/AST/Visitor.hpp
===================================================================
--- src/AST/Visitor.hpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Visitor.hpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -33,5 +33,5 @@
     virtual const ast::DirectiveDecl *    visit( const ast::DirectiveDecl        * ) = 0;
     virtual const ast::StaticAssertDecl * visit( const ast::StaticAssertDecl     * ) = 0;
-    virtual const ast::DeclWithType *     visit( const ast::InlineValueDecl      * ) = 0;
+    virtual const ast::DeclWithType *     visit( const ast::InlineMemberDecl      * ) = 0;
     virtual const ast::CompoundStmt *     visit( const ast::CompoundStmt         * ) = 0;
     virtual const ast::Stmt *             visit( const ast::ExprStmt             * ) = 0;

Index: src/AST/Convert.cpp
===================================================================
--- src/AST/Convert.cpp	(revision 44547b021e0a0a8176807a187bc5c1c80a63e39b)
+++ src/AST/Convert.cpp	(revision 71806e0f8878eff4daf459af6ea5ef2c730185da)
@@ -236,6 +236,6 @@
 	}
 
-	// InlineValueDecl vanish after EnumAndPointerDecay pass so no necessary to implement NewToOld
-	const ast::DeclWithType * visit( const ast::InlineValueDecl * node ) override final {	
+	// InlineMemberDecl vanish after EnumAndPointerDecay pass so no necessary to implement NewToOld
+	const ast::DeclWithType * visit( const ast::InlineMemberDecl * node ) override final {	
 		assert( false );
 		(void) node;
@@ -1869,5 +1869,5 @@
 	}
 
-	virtual void visit( const InlineValueDecl * old ) override final {
+	virtual void visit( const InlineMemberDecl * old ) override final {
 		if ( inCache( old ) ) {
 			return;
@@ -1876,5 +1876,5 @@
 		auto&& attr = GET_ACCEPT_V(attributes, Attribute);
  
-		auto decl = new ast::InlineValueDecl(
+		auto decl = new ast::InlineMemberDecl(
 			old->location,
 			old->name,